Enum romu::SeedSource [−][src]
pub enum SeedSource {
GetRandom,
Std,
MemoryAddress,
User,
Fixed,
}Expand description
Defines which source the seed was created from.
Variants
GetRandom
The crate getrandom was used to create the seed from a high quality randomness source
of the operating system.
Std
The standard library was used to get a low quality randomness seed from three sources:
- Hash of the current time instance.
- Hashed thread ID.
- Memory Address.
MemoryAddress
Use a static memory address as a low randomness seed. If Address Space Layout Randomization (ASLR) is supported by the operating system, this should be a pretty “random” value.
User
Seed was provided by the user.
Fixed
Fixed value by the implementation.