Struct romu::Rng128[][src]

pub struct Rng128 { /* fields omitted */ }
Implements RomuTrio with 128-bit width.

Implementations

Creates a new Rng128 with a seed from the best available randomness source.

Creates a new Rng128 from the given two 64-bit seeds.

The seeds should be from a high randomness source.

Creates a new Rng128 from the given two 192-bit seeds.

The seeds should be from a high randomness source.

If the seeds are of low quality, user should call Rng128::mix() to improve the quality of the first couple of random numbers.

Notice

The variables must be seeded such that at least one bit of state is non-zero.

Mixes the states, which should improve the quality of the random numbers.

Should be called when having (re-)seeded the generator with a fixed value of low randomness.

Re-seeds the Rng128 from the best available randomness source.

Generates two random u64 values.

Fills a mutable [u8] slice with random values.